#!/bin/sh -e
# Copyright GD (C)2004
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $Id: up.m4,v 1.7 2006/12/18 13:56:17 gd Exp $

genclass=mysql
suffix=
inclass=mysql
. ${JAILUP_CONF}
kind=`${dirname} "${0}"`
kind=`${basename} "${kind}"`
t=`${basename} "${0}"`
if  [ "${t}" != "${t#*-}" ]; then
    kind="${kind}/-${t#*-}"
fi

if  [ -z "${1}" ]; then
    ${cat} << EOF
# jailup ${inclass} dir jailname jailaddr
#     where jailname - hostname for jail (see jail(2) hostname)
#           jailaddr - IP addr for jail (see jail(2) ip_number)
#           dir relative to ${JAILUPDIR} and ${JAILRODIR}
# installed ports/databases/mysql50-server used
EOF
    exit
fi
umask 022

jdir="${1}"
jailsname="${2}"
jailsaddr="${3}"
main_dir="${JAILUPDIR}/${jdir}"
conf_dir="${JAILRODIR}/${jdir}"

${mkdir} "${main_dir}" "${conf_dir}"
${up_mdir} "${main_dir}" ${MTREE}

ETCOPY(resolv.conf localtime)

${up_ldsh} << EOF | ${up_shlib} "${main_dir}/usr/lib"
    /usr/local/libexec/mysqld
EOF

${up_libexe} "${main_dir}/usr/libexec" << EOF
    ld-elf.so.1
    mysqld
EOF

${up_data} "${main_dir}/usr/share/mysql" /usr/local/share/mysql/ << EOF
    /charsets/Index.xml
    /charsets/cp1251.xml
    /charsets/koi8r.xml
    /charsets/latin1.xml
    /english/errmsg.sys
EOF

      #####################################
      ####                             ####
      #### Begin of etc fill           ####
      ####                             ####
${up_ponf} "${conf_dir}/my.cnf" << "EOF"
[mysqld]
socket          = /tmp/mysql.sock
pid-file	= /var/run/mysql.pid
skip-locking
key_buffer = 16K
max_allowed_packet = 1M
table_cache = 4
sort_buffer_size = 64K
net_buffer_length = 2K
thread_stack = 64K
tmpdir=/tmp
skip-networking
skip-bdb
skip-innodb
basedir = /usr
user = mysql
log_error = error.log
log-slow-queries = slow_queries.log
skip-name-resolve
query_cache_type = 1
query_cache_size=32M
# for KOI8-R
default-character-set = koi8r
character-set-server = koi8r
collation-server = koi8r_general_ci
default-collation = koi8r_general_ci
# for CP1251
#default-character-set = cp1251
#character-set-server = cp1251
#collation-server = cp1251_general_ci
#default-collation = cp1251_general_ci
EOF

${up_ponf} "${conf_dir}/group" << "EOF"
wheel:*:0:root
mysql:*:88:
EOF

${up_ponf} "${conf_dir}/master.passwd" << "EOF"
root:*:0:0::0:0:Charlie &:/:/nonexistent
mysql:*:88:88::0:0:Mysql server:/var/db/mysql:/nonexistent
EOF
      ####                             ####
      #### End of etc fill             ####
      ####                             ####
      #####################################

${up_mtree} "${main_dir}" ${MTREE}
${mtree} -Ueqxp "${conf_dir}" << "EOF"
/set type=file uname=root gname=wheel mode=0644 flags=none
.				type=dir mode=0755
    group
    master.passwd		mode=0600
    my.cnf
EOF

${pwd_mkdb} -d "${conf_dir}" -p "${conf_dir}/master.passwd"

${cat} << EOF >> "${genconfig}"
#${genclass}	${inclass}	${jdir}	${jailsname}	${jailsaddr}	0	88	88
EOF
      #####################################
      ####                             ####
      #### Begin of fstab mod          ####
      ####                             ####
${cat} << EOF >> "${etcdir}/fstab"
#${conf_dir}		${main_dir}/etc	null	ro,nodev,noexec	0 0
EOF
      ####                             ####
      #### End of fstab mod            ####
      ####                             ####
      #####################################

mysql_db="${main_dir}/var/db/mysql"
mysql_bootstrap="${PREFIX}/libexec/mysqld --bootstrap --skip-grant-tables \
                     --basedir=/usr/local --datadir=${mysql_db} --skip-innodb \
                     --skip-bdb --skip-ndbcluster --max_allowed_packet=8M \
                     --net_buffer_length=16K"

# Check for old tables
if [ ! -f "${mysql_db}/mysql/user.frm" ]
then
    ${PREFIX}/bin/mysql_create_system_tables \
        real "${mysql_db}" 127.0.0.1 0 |\
        ${mysql_bootstrap}

    ( echo 'use mysql;' ;\
      ${cat} ${PREFIX}/share/mysql/fill_help_tables.sql ;\
      echo 'DELETE FROM db WHERE Db LIKE "test%";' ) |\
    ${mysql_bootstrap}
    
    chown -R mysql:mysql ${mysql_db}
fi
